summaryrefslogtreecommitdiffstats
path: root/sw/qa/uitest/writer_tests3/hyperlinkdialog.py
diff options
context:
space:
mode:
Diffstat (limited to 'sw/qa/uitest/writer_tests3/hyperlinkdialog.py')
-rw-r--r--sw/qa/uitest/writer_tests3/hyperlinkdialog.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/sw/qa/uitest/writer_tests3/hyperlinkdialog.py b/sw/qa/uitest/writer_tests3/hyperlinkdialog.py
index ff1a30931b5a..dc1a4c0f12b8 100644
--- a/sw/qa/uitest/writer_tests3/hyperlinkdialog.py
+++ b/sw/qa/uitest/writer_tests3/hyperlinkdialog.py
@@ -87,12 +87,12 @@ class HyperlinkDialog(UITestCase):
# opened in the user's default browser):
if os.getenv('ENABLE_HTMLHELP') == 'TRUE':
return
# Skip this test for --with-help, as that would fail with a
# "uno.com.sun.star.uno.RuntimeException: Could not find child with id: cancel" thrown from
# the below execute_blocking_action call, as it would open the "LibreOffice Help" window
# instead of the apparently expected "LibreOffice Help Not Installed" dialog that has a
# "Cancel" button:
- if re.compile(r'-DWITH_HELP\b').search(os.getenv('SCPDEFS')):
+ if re.compile(r'XMLHELP\b').search(os.getenv('BUILD_TYPE')):
return
self.ui_test.create_doc_in_start_center("writer")
@@ -87,12 +87,12 @@ class HyperlinkDialog(UITestCase):
if os.getenv('ENABLE_HTMLHELP') == 'TRUE':
return
- # Skip this test for --with-help, as that would fail with a
+ # Skip this test for --with-xmlhelp, as that would fail with a
# "uno.com.sun.star.uno.RuntimeException: Could not find child with id: cancel" thrown from
# the below execute_blocking_action call, as it would open the "LibreOffice Help" window